Module: UniversalTrackManager

Defined in:
lib/helios_tracker.rb

Overview

UTM’s entry point (universal-track-manager.rb) loads models before defining the module, which breaks on Rails 8+. We pre-define the module so models

can reference UniversalTrackManager

constants, then load the full entry

point which brings in models, concerns, and finally reopens the module to add .configure and friends.